export { useLocalStorage, useMergeRefs, useUncontrolled, useUniqueId } from '@versini/ui-hooks';
import * as React$1 from 'react';
import React__default from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { Placement } from '@floating-ui/react';

type SpacingType =
	| undefined
	| string
	| number
	| {
			t?: number;
			r?: number;
			b?: number;
			l?: number;
	  };

type CommonButtonProps = {
	children: React.ReactNode;
	kind?: "dark" | "light";
	focus?: "dark" | "light";
	fullWidth?: boolean;
	className?: string;
	raw?: boolean;
	noBorder?: boolean;
	labelRight?: string;
	spacing?: SpacingType;
};

declare const Anchor: React__default.ForwardRefExoticComponent<{
    children?: React__default.ReactNode;
    link?: string | undefined;
    target?: string | undefined;
    maxLabelLength?: number | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
    noTruncate?: boolean | undefined;
} & {
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type BubbleProps = {
	children: React.ReactNode;
	kind?: "left" | "right";
	className?: string;
	footer?: {
		[key: string]: string | number | undefined | null;
	};
	rawFooter?: React.ReactNode;
	copyToClipboard?: boolean | string | ((text: any) => void);
	spacing?: SpacingType;
};

declare const Bubble: ({ children, kind, className, footer, rawFooter, copyToClipboard, spacing, }: BubbleProps) => react_jsx_runtime.JSX.Element;

declare const Button: React__default.ForwardRefExoticComponent<{
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonIcon: React__default.ForwardRefExoticComponent<{
    label?: string | undefined;
    children: React__default.ReactNode;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonLink: React__default.ForwardRefExoticComponent<{
    children?: React__default.ReactNode;
    link?: string | undefined;
    target?: string | undefined;
    maxLabelLength?: number | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
    noTruncate?: boolean | undefined;
} & {
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type CardProps = {
	className?: string;
	header?: React.ReactNode;
	headerClassName?: string;
	footer?: React.ReactNode;
	footerClassName?: string;
	children: React.ReactNode;
	noBackground?: boolean;
	"aria-labelledby"?: string;
	spacing?: SpacingType;
};

declare const Card: ({ header, headerClassName, footer, footerClassName, children, noBackground, className, "aria-labelledby": ariaLabelledby, spacing, ...otherProps }: CardProps) => react_jsx_runtime.JSX.Element;

type FlexgridProps = {
	/**
	 * Children of the Flexgrid (FlexgridItem(s) or any other nodes).
	 */
	children: React.ReactNode;

	/**
	 * Equivalent to "justify-content" in flexbox, this prop defines
	 * the alignment along the main axis (horizontal).
	 */
	alignHorizontal?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "space-between"
		| "space-around"
		| "space-evenly";

	/**
	 * Equivalent to "align-items" in flexbox, this prop defines
	 * the alignment along the cross axis (vertical).
	 */
	alignVertical?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "stretch"
		| "baseline";

	/**
	 * The class name of the Flexgrid.
	 * It follows the [CSS class name property](https://developer.mozilla.org/en-US/docs/Web/CSS/class).
	 */
	className?: string;

	/**
	 * Width of the gutters between the columns.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	columnGap?: number;

	/**
	 * Equivalent to "flex-direction" in flexbox, this prop
	 * establishes the main-axis, thus defining the direction
	 * flex items are placed in the flex container. Flexbox is
	 * (aside from optional wrapping) a single-direction layout
	 * concept. Think of flex items as primarily laying out
	 * either in horizontal rows or vertical columns.
	 */
	direction?: "row" | "row-reverse" | "column" | "column-reverse";

	/**
	 * The height of the Flexgrid.
	 * It follows the [CSS height property](https://developer.mozilla.org/en-US/docs/Web/CSS/height).
	 */
	height?: string;

	/**
	 * Width of the gutters between the rows.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	rowGap?: number;

	/**
	 * The width of the Flexgrid.
	 * It follows the [CSS width property](https://developer.mozilla.org/en-US/docs/Web/CSS/width).
	 */
	width?: string;
};

type FlexgridItemProps = {
	/** Children of the FlexgridItem. */
	children?: React.ReactNode;

	/** Classname to apply to the FlexgridItem. */
	className?: string;

	/** The item will span across the provided number of grid tracks. */
	span?: number | "auto";
};

declare const Flexgrid: ({ children, className, columnGap, rowGap, height, width, direction, alignHorizontal, alignVertical, ...otherProps }: FlexgridProps) => react_jsx_runtime.JSX.Element;

/**
 * FlexgridItem is a child of Flexgrid. It is used to define the width of a
 * column in a Flexgrid. It can be used to span across multiple columns in a
 * Flexgrid by providing a number of columns or "auto" value to the `span` prop.
 */
declare const FlexgridItem: ({ children, className, span, ...otherProps }: FlexgridItemProps) => react_jsx_runtime.JSX.Element;

type FooterProps = {
	kind?: "dark" | "light";
	className?: string;
	noPaddings?: boolean;
	row1?: React.ReactNode;
	row2?: React.ReactNode;
	spacing?: SpacingType;
};

declare const Footer: ({ className, kind, row1, row2, noPaddings, spacing, }: FooterProps) => react_jsx_runtime.JSX.Element;

interface IconsProps
	extends Omit<React.SVGAttributes<SVGElement>, "spacing"> {
	spacing?: SpacingType;
	decorative?: boolean;
	monotone?: boolean;
	title?: string;
}

declare const IconBack: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconChart: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconClose: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopied: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopy: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDelete: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDog: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconEdit: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconHide: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconHistory: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconInfo: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconProfile: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconRestore: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconSettings: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconShow: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconUser: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

type MainProps = {
	children: React.ReactNode;
	className?: string;
	raw?: boolean;
	spacing?: SpacingType;
};

declare const Main: ({ children, className, raw, spacing, }: MainProps) => react_jsx_runtime.JSX.Element;

interface MenuProps {
	icon?: React.ReactNode;
	label?: string;
	children?: React.ReactNode;
	defaultPlacement?: Placement;
	onOpenChange?: (open: boolean) => void;
	spacing?: SpacingType;
}

interface MenuItemProps {
	label: string;
	disabled?: boolean;
	icon?: React.ReactNode;
}

type MenuSeparatorProps = React.HTMLAttributes<HTMLDivElement>;

declare const Menu: React$1.ForwardRefExoticComponent<Omit<MenuProps & React$1.HTMLProps<HTMLButtonElement>, "ref"> & React$1.RefAttributes<HTMLButtonElement>>;

declare const MenuItem: React$1.ForwardRefExoticComponent<MenuItemProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;
declare const MenuSeparator: ({ className, ...props }: MenuSeparatorProps) => react_jsx_runtime.JSX.Element;

declare const TYPE_PANEL = "panel";
declare const TYPE_MESSAGEBOX = "messagebox";

type PanelProps = {
	open: boolean;
	onOpenChange: (open: boolean) => void;
	title: string;
	children: React.ReactNode;
	footer?: React.ReactNode;
	borderKind?: "dark" | "light";
	kind?: typeof TYPE_PANEL | typeof TYPE_MESSAGEBOX;
};

declare const Panel: ({ open, onOpenChange, title, children, footer, borderKind, kind, }: PanelProps) => react_jsx_runtime.JSX.Element;

type SpinnerProps = {
	spinnerRef?: React.RefObject<HTMLDivElement>;
	kind?: "dark" | "light";
	type?: "circle" | "dots";
	spacing?: SpacingType;
};

declare const Spinner: ({ spinnerRef, kind, type, spacing, }: SpinnerProps) => react_jsx_runtime.JSX.Element;

type TableProps = {
	kind?: "dark" | "light";
	/**
	 * This attribute defines the caption (or title) of a table.
	 */
	caption?: React__default.ReactNode;
	/**
	 * This attribute defines an alternative text that summarizes
	 * the content of the table. It is not visible but will be
	 * read out loud by screen readers to represent the table.
	 */
	summary?: string;
	/**
	 * The max height of the table. It follows the CSS max-height property.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	maxHeight?: string;
	/**
	 * If true, the table header will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyHeader?: boolean;
	/**
	 * Custom spacing for the component.
	 */
	spacing?: SpacingType;
} & React__default.HTMLAttributes<HTMLTableElement>;

type TableRowProps = React__default.HTMLAttributes<HTMLTableRowElement>;
type TableBodyProps = React__default.HTMLAttributes<HTMLTableSectionElement>;
type TableHeadProps = React__default.HTMLAttributes<HTMLTableSectionElement>;

type TableCellProps = {
	component?: "td" | "th";
} & React__default.ThHTMLAttributes<HTMLTableCellElement> &
	React__default.TdHTMLAttributes<HTMLTableCellElement>;

declare const Table: ({ children, kind, caption, summary, className, maxHeight, stickyHeader, spacing, ...otherProps }: TableProps) => react_jsx_runtime.JSX.Element;
declare const TableHead: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableBody: ({ children, ...otherProps }: TableBodyProps) => react_jsx_runtime.JSX.Element;
declare const TableRow: ({ children, className, ...otherProps }: TableRowProps) => react_jsx_runtime.JSX.Element;
declare const TableCell: ({ children, component, className, ...otherProps }: TableCellProps) => react_jsx_runtime.JSX.Element;

declare const TextArea: React__default.ForwardRefExoticComponent<{
    label: string;
    name: string;
    labelId?: string | undefined;
    helperText?: string | undefined;
    helperTextOnFocus?: boolean | undefined;
    error?: boolean | undefined;
    focusKind?: "dark" | "light" | undefined;
    borderKind?: "dark" | "light" | undefined;
    errorKind?: "dark" | "light" | undefined;
    raw?: boolean | undefined;
    noBorder?: boolean | undefined;
    textAreaClassName?: string | undefined;
    rightElement?: React__default.ReactElement<any, string | React__default.JSXElementConstructor<any>> | undefined;
    spacing?: SpacingType;
} & React__default.TextareaHTMLAttributes<HTMLTextAreaElement> & React__default.RefAttributes<HTMLTextAreaElement>>;

declare const TextInput: React__default.ForwardRefExoticComponent<{
    rightElement?: React__default.ReactElement<any, string | React__default.JSXElementConstructor<any>> | undefined;
} & {
    label: string;
    name: string;
    labelId?: string | undefined;
    helperText?: string | undefined;
    error?: boolean | undefined;
    focusKind?: "dark" | "light" | undefined;
    borderKind?: "dark" | "light" | undefined;
    errorKind?: "dark" | "light" | undefined;
    raw?: boolean | undefined;
    noBorder?: boolean | undefined;
    inputClassName?: string | undefined;
    spacing?: SpacingType;
} & React__default.InputHTMLAttributes<HTMLInputElement> & React__default.RefAttributes<HTMLInputElement>>;

declare const TextInputMask: React__default.ForwardRefExoticComponent<{
    onMaskChange?: (({ e, masked, }: {
        e: React__default.SyntheticEvent<Element, Event>;
        masked: boolean;
    }) => void) | undefined;
    onTextInputMaskBlur?: (() => void) | undefined;
} & {
    label: string;
    name: string;
    labelId?: string | undefined;
    helperText?: string | undefined;
    error?: boolean | undefined;
    focusKind?: "dark" | "light" | undefined;
    borderKind?: "dark" | "light" | undefined;
    errorKind?: "dark" | "light" | undefined;
    raw?: boolean | undefined;
    noBorder?: boolean | undefined;
    inputClassName?: string | undefined;
    spacing?: SpacingType;
} & React__default.InputHTMLAttributes<HTMLInputElement> & React__default.RefAttributes<HTMLInputElement>>;

type ToggleProps = {
	label: string;
	name: string;
	checked: boolean;
	onChange: (checked: boolean) => void;
	labelHidden?: boolean;
	kind?: "dark" | "light";
	spacing?: SpacingType;
};

declare const Toggle: ({ checked, onChange, label, labelHidden, name, kind, spacing, }: ToggleProps) => react_jsx_runtime.JSX.Element;

export { Anchor, Bubble, Button, ButtonIcon, ButtonLink, Card, Flexgrid, FlexgridItem, Footer, IconBack, IconChart, IconClose, IconCopied, IconCopy, IconDelete, IconDog, IconEdit, IconHide, IconHistory, IconInfo, IconProfile, IconRestore, IconSettings, IconShow, IconUser, Main, Menu, MenuItem, MenuSeparator, Panel, Spinner, Table, TableBody, TableCell, TableHead, TableRow, TextArea, TextInput, TextInputMask, Toggle };
